@@ -17,7 +17,7 @@
 ## @deftypefn {Function File} @var{warped} = imremap (@var{im}, @var{XI}, @var{YI})
 ## @deftypefnx{Function File} @var{warped} = imremap (@var{im}, @var{XI}, @var{YI}, @var{interp}, @var{extrapval})
 ## @deftypefnx{Function File} @var{warped} = imremap (@var{im}, @var{XI}, @var{YI}, "bicubic", @var{padding})
-## Applies any geometric transformation to the image @var{im}.
+## Applies any geometric transformation to a given image.
 ##
 ## The arguments @var{XI} and @var{YI} are lookup tables that define the resulting
 ## image
@@ -122,7 +122,7 @@ function [warped] = imremap (im, XI, YI, interp = "linear", extrapval = 0)
         else
           warped(:,:,i) = extrapval;
         endif
-      # 2d image planes:
+      # 2D image planes:
       else
         warped(:,:,i) = interp2 (double (im(:,:,i)), XI, YI, interp, extrapval);
       endif
@@ -176,7 +176,7 @@ function idx = pad_indices (i, sz, method = "symmetric")
   endif
 endfunction
 
-## extract elements using meshgrid from 2d or 3d matrix
+## extract elements using meshgrid from 2D or 3D matrix
 function B = idx3 (A, Y, X)
   sz = size(A);
   if (length (sz) == 2)
@@ -184,7 +184,7 @@ function B = idx3 (A, Y, X)
   else
     X3 = repmat (X, [1, 1, sz(3)]);
     Y3 = repmat (Y, [1, 1, sz(3)]);
-    ## Z is simply a 3d matrix, where the first channel is full of 1s, the second full of 2s, etc.
+    ## Z is simply a 3D matrix, where the first channel is full of 1s, the second full of 2s, etc.
     Z3 = reshape (repelem (1:sz(3), size (X, 1) * size (X, 2), 1), ...
         [size(X,1), size(X,2), sz(3)]);
     i = sub2ind (sz, Y3, X3, Z3);
