@@ -120,7 +120,7 @@ function [varargout] = imtransform (im, T, varargin)
       if (!any (tst))
         error ("imtransform: expect one of %s as interp method", disp (allowed));
       else
-        interp = {"pchip", "linear", "nearest"}{find (tst)};
+        interp = {"cubic", "linear", "nearest"}{find (tst)};
       endif
       varargin = varargin(2:end);
     endif
@@ -257,17 +257,34 @@ function [varargout] = imtransform (im, T, varargin)
   [xx yy] = meshgrid (linspace (xdata(1), xdata(2), imsize(2)),
                       linspace (ydata(1), ydata(2), imsize(1)));
 
-  [uu vv] = meshgrid (linspace (udata(1), udata(2), size(im)(2)),
-                      linspace (vdata(1), vdata(2), size(im)(1)));
+  uu = linspace (udata(1), udata(2), size(im)(2));
+  vv = linspace (vdata(1), vdata(2), size(im)(1));
 
   ## Input coordinates
   [uui, vvi] = tforminv (T, reshape (xx, numel (xx), 1),
                          reshape (yy, numel (yy), 1));
   uui = reshape (uui, size (xx));
   vvi = reshape (vvi, size (yy));
-  ## Interpolation
+
+  ## Interpolation:
+  ## For compatibility with Matlab, pad the original image
+  ## with fillvalues before interpolation and interpolate  (see bug #67682)
+  du = uu(2) - uu(1);
+  uu = [uu(1)-3*du uu(1)-2*du uu(1)-du uu uu(end)+du uu(end)+2*du uu(end)+3*du];
+  dv = vv(2) - vv(1);
+  vv = [vv(1)-3*dv vv(1)-2*dv vv(1)-dv vv vv(end)+dv vv(end)+2*dv vv(end)+3*dv];
+
+  ## For compatibility with Matlab, cast image to double for interpolation
+  ## and cast back to desired type (see bug #67682)
+  cls = class (im);
+  do_cast = ! strcmp (cls, "double");
+  if (do_cast)
+    im = double (im);
+  endif
+
   for layer = 1:imdepth
-    imout(:,:,layer) = interp2 (uu, vv, im(:,:,layer), ...
+    imout(:,:,layer) = interp2 (uu, vv, padarray (im(:,:,layer), [3, 3], ...
+                                                  fillvalues(layer)), ...
                                 uui, vvi, interp, fillvalues(layer));
     if (xdir == -1)
       imout(:,:,layer) = fliplr (imout(:,:,layer));
@@ -276,6 +293,11 @@ function [varargout] = imtransform (im, T, varargin)
       imout(:,:,layer) = flipud (imout(:,:,layer));
     endif
   endfor
+
+  if (do_cast)
+    imout = cast (imout, cls);
+  endif
+
   if (nargout != 0)
     # revert xdata and ydata to original values
     if (xdir == -1)
