@@ -55,7 +55,7 @@
 ## image based on its projections.
 ##
 ## Filtered back-projection is the most common means of reconstructing
-## images from CT scans.  It is a two step process: First, each of
+## images from CT scans.  It is a two-step process: First, each of
 ## the projections is filtered with a `rho filter', so named due
 ## to its frequency domain definition, which is simply |rho|, where
 ## rho is the radial axis in a polar coordinate system.  Second,
@@ -84,56 +84,55 @@ function [recon, filt] = iradon (proj, theta, interp, filter, scaling, output_si
   if (nargin < 6)
     output_size = 2 * floor (size (proj, 1) / (2 * sqrt (2)));
   endif
-  if (nargin < 5) || (length (scaling) == 0)
+  if (nargin < 5 || isempty (scaling))
     scaling = 1;
   endif
-  if (nargin < 4) || (length (filter) == 0)
+  if (nargin < 4 || isempty (filter))
     filter = "Ram-Lak";
   endif
-  if (nargin < 3) || (length (interp) == 0)
+  if (nargin < 3 || isempty (interp))
     interp = "linear";
   endif
-  if (nargin < 2) || (length (theta) == 0)
+  if (nargin < 2 || isempty (theta))
     theta = 180 * (0:1:size (proj, 2) - 1) / size (proj, 2);
   endif
 
-  if (isscalar (theta)) && (size (proj, 2) != 1)
+  if (isscalar (theta) && size (proj, 2) != 1)
     theta = (0:size (proj, 2) - 1) * theta;
   endif
 
   if (length (theta) != size (proj, 2))
-    error ("iradon: Number of projections does not match number of angles")
+    error ("iradon: Number of projections does not match number of angles");
   endif
   if (!isscalar (scaling))
     error ("iradon: Frequency scaling value must be a scalar");
   endif
-  if (!length (find (strcmpi (interp, {'nearest', 'linear', 'spline', ...
-                                       'pchip', 'cubic'}))))
-    error ("iradon: Invalid interpolation method specified");
+  valid_interpolations = {"nearest", "linear", "spline", "pchip", "cubic"};
+  if (!any (strcmpi (interp, valid_interpolations)))
+    error ("iradon: Invalid interpolation method specified. Supported methods: %s", strjoin(valid_interpolations, ", "));
   endif
 
   ## Convert angles to radians
   theta *= pi / 180;
 
-  ## First, filter the projections
+  ## Filter the projections
   [filtered, filt] = rho_filter (proj, filter, scaling);
 
-  ## Next, back-project
+  ## Perform back-projection
   recon = back_project (filtered, theta, interp, output_size);
 
 endfunction
 
 
 function recon = back_project (proj, theta, interpolation, dim)
-  ## Make an empty image
+  ## Create an empty image
   recon = zeros (dim, dim);
 
-  ## Zero pad the projections if the requested image
-  ## has a diagonal longer than the projections
+  ## Zero pad projections if the image diagonal exceeds projection size
   diagonal = ceil (dim * sqrt (2)) + 1;
   if (size (proj, 1) < diagonal)
-    diff = 2 * ceil ((diagonal - size (proj, 1)) / 2);
-    proj = padarray (proj, diff / 2);
+    padding = ceil ((diagonal - size (proj, 1)) / 2);
+    proj = padarray (proj, padding);
   endif
 
   ## Create the x & y values for each pixel
@@ -149,8 +148,8 @@ function recon = back_project (proj, theta, interpolation, dim)
 
   ## Sum each projection's contribution
   for i = 1:length (theta)
-    s_dash = (x * cos (theta (i)) + y * sin (theta (i)));
-    interpolated = interp1 (s, proj (:, i), s_dash (:), ["*", interpolation]);
+    s_dash = x * cos (theta(i)) + y * sin (theta(i));
+    interpolated = interp1 (s, proj(:, i), s_dash(:), ["*", interpolation]);
     recon += reshape (interpolated, dim, dim);
   endfor
 
